@@ -194,9 +194,9 @@ class Platform(object):
     def is_unix(name=None):
         """Return true if the platform is a unix, False otherwise. """
         name = name or sys.platform
-        return (Platform.is_darwin() or
-                Platform.is_linux() or
-                Platform.is_freebsd()
+        return (Platform.is_darwin()
+                or Platform.is_linux()
+                or Platform.is_freebsd()
                 )
 
     @staticmethod
@@ -686,7 +686,7 @@ def chunks(iterable, chunk_size):
         count = 0
         try:
             for _ in range(chunk_size):
-                chunk[count] = iterable.next()
+                chunk[count] = next(iterable)
                 count += 1
             yield chunk[:count]
         except StopIteration:
