@@ -428,6 +428,9 @@ def parse_arguments(parser):
     parser.add_argument('--monasca_statsd_port',
                         help="Statsd daemon port number",
                         default=8125)
+    parser.add_argument('--monasca_statsd_interval',
+                        help="Statsd metric aggregation interval (seconds)",
+                        default=20)
     parser.add_argument('--agent_service_name',
                         help="agent's systemd/sysv service name",
                         required=False,
@@ -469,8 +472,12 @@ def plugin_detection(
                 plugin_config.merge(new_config)
         elif not skip_failed:
             LOG.warning("Failed detection of plugin %s."
-                        "\n\tPossible causes: Service not found or missing"
-                        "arguments.", detect.name)
+                        "\n\tPossible causes: Service not found or missing arguments. "
+                        "\n\tFor services, the service is required to be running at "
+                        "detection time. For other plugins, check the args (paths, "
+                        "urls, etc)."
+                        "\n\tDetection may also fail if monasca-agent services "
+                        "(statsd, forwarder, collector) are not running.", detect.name)
             return None
 
     return plugin_config
